@@ -53,7 +53,9 @@ __all__ = (
     "WorldExportJobStatusType",
     "WorldGenerationJobErrorCodeType",
     "WorldGenerationJobStatusType",
+    "RoboMakerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -199,6 +201,7 @@ WorldGenerationJobErrorCodeType = Literal[
 WorldGenerationJobStatusType = Literal[
     "Canceled", "Canceling", "Completed", "Failed", "PartialFailed", "Pending", "Running"
 ]
+RoboMakerServiceName = Literal["robomaker"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -352,6 +355,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -500,6 +504,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_deployment_jobs",
     "list_fleets",
